@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2020, Brandon Nielsen
+# Copyright (c) 2021, Brandon Nielsen
 # All rights reserved.
 #
 # This software may be modified and distributed under the terms
@@ -11,6 +11,6 @@ import sys
 PY2 = sys.version_info[0] == 2
 
 if PY2:
-    import mock
+    import mock  # pylint: disable=import-error
 else:
     from unittest import mock
